@@ -12,6 +12,16 @@ class Commit(object):
         self.files = files
         self.diff = diff
 
+    def _get_diff(self):
+        if callable(self._diff):
+            self._diff = self._diff()
+        return self._diff
+
+    def _set_diff(self, diff):
+        self._diff = diff
+
+    diff = property(_get_diff, _set_diff)
+
     def __str__(self):
         return "<Commit %s by %s on %s>" % (self.commit_id, self.author, self.time)
 
